==> yy_core-1.0.0.tar.gz: yy_core-1.0.0/yy_core/models/db_models/stat/stat_report_model.py <==
# -*- coding: utf-8 -*-
"""
@Author: yy
@Date: 2021-07-26 09:40:36
@LastEditTime: 2023-07-19 11:14:53
@LastEditors: yy
@Description: 
"""
#此文件由rigger自动生成
from yy_core.mysql import MySQLHelper
from yy_core.base_model import *
from yy_core.models.cache_model import *


class StatReportModel(CacheModel):
    def __init__(self, db_connect_key='db_yy', sub_table=None, db_transaction=None, context=None, is_auto=False):
        super(StatReportModel, self).__init__(StatReport, sub_table)
        db_connect_key, self.redis_config_dict = CoreHelper.get_connect_config("db_stat","redis_stat", db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_connect_key, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类

class StatReport:

    def __init__(self):
        super(StatReport, self).__init__()
        self.id = 0  # id
        self.app_id = ""  # 应用标识
        self.act_id = 0  # 活动标识
        self.module_id = 0  # 活动模块标识
        self.object_id = ""  # 对象标识
        self.key_name = ""  # key名称
        self.key_value = 0  # key值
        self.create_day = 0  # 创建天
        self.create_month = 0  # 创建月
        self.create_year = 0  # 创建年
        self.create_date = "1900-01-01 00:00:00"  # 创建时间

    @classmethod
    def get_field_list(self):
        return ['id', 'app_id', 'act_id', 'module_id', 'object_id', 'key_name', 'key_value', 'create_day', 'create_month', 'create_year', 'create_date']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "stat_report_tb"

==> yy_core-1.0.11.tar.gz: yy_core-1.0.11/yy_core/models/db_models/stat/stat_report_model.py <==
# -*- coding: utf-8 -*-
"""
@Author: yy
@Date: 2021-07-26 09:40:36
@LastEditTime: 2023-07-19 11:14:53
@LastEditors: yy
@Description: 
"""
#此文件由rigger自动生成
from yy_core.mysql import MySQLHelper
from yy_core.base_model import *
from yy_core.cache_model import *


class StatReportModel(CacheModel):
    def __init__(self, db_connect_key='db_yy', sub_table=None, db_transaction=None, context=None, is_auto=False):
        super(StatReportModel, self).__init__(StatReport, sub_table)
        db_connect_key, self.redis_config_dict = CoreHelper.get_connect_config("db_stat","redis_stat", db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_connect_key, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类

class StatReport:

    def __init__(self):
        super(StatReport, self).__init__()
        self.id = 0  # id
        self.app_id = ""  # 应用标识
        self.act_id = 0  # 活动标识
        self.module_id = 0  # 活动模块标识
        self.object_id = ""  # 对象标识
        self.key_name = ""  # key名称
        self.key_value = 0  # key值
        self.create_day = 0  # 创建天
        self.create_month = 0  # 创建月
        self.create_year = 0  # 创建年
        self.create_date = "1900-01-01 00:00:00"  # 创建时间

    @classmethod
    def get_field_list(self):
        return ['id', 'app_id', 'act_id', 'module_id', 'object_id', 'key_name', 'key_value', 'create_day', 'create_month', 'create_year', 'create_date']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "stat_report_tb"
